{
    package GCLang::IT;
    
    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################

    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (

        'LangName' => 'Italiano',
        
        'Separator' => ': ',
        
        'Warning' => '<b>Warning</b>:
        
Information downloaded from Internet sites (thanks to 
search plugins) are only for <b>personal use</b>

Any re-distribution is forbidden whithout <b>explicit
web sites authorisation</b>.

To know which is the web site owning information, you
can use <b>button below film details</b>.',
        
        'AllItemsFiltered' => 'No item matches your filtering criteria',

#Installation
        'InstallDirInfo' => 'Installazione dentro ',
        'InstallMandatory' => 'Componenti obbligatori',
        'InstallOptional' => 'Componenti Facoltativi',
        'InstallErrorMissing' => 'Errore : I seguenti componenti devono essere installati: ',
        'InstallPrompt' => 'Indice per installazione [/usr/local]: ',
        'InstallEnd' => 'Estremità dell\'installazione',
        'InstallNoError' => 'Nessun errore',
        'InstallLaunch' => 'Per usare questa applicazione, si può lanciare ',
        'InstallDirectory' => 'Indice basso',
        'InstallTitle' => 'Installazione di GCstar',
        'InstallDependencies' => 'Dipendenze',
        'InstallPath' => 'Path',
        'InstallOptions' => 'Options',
        'InstallSelectDirectory' => 'Selezioni l\'indice basso per l\'installazione',
        'InstallWithClean' => 'Rimuovi files trovati nella directory di installazione',
       	'InstallWithMenu' => 'Add GCstar to Applications menu',
       	'InstallNoPermission' => 'Error: You don\'t have permission to write in the selected directory',
        'InstallMissingMandatory' => 'Mandatory dependencies are missing. You won\'t be able to install GCstar until they have been added to your system.',
        'InstallMissingOptional' => 'Some optional dependencies are missing. There are listed under. GCstar may be installed but some features won\'t be available.',
        'InstallMissingNone' => 'There are no missing dependency. You may continue and install GCstar.',
        'InstallOK' => 'OK',
        'InstallMissing' => 'Missing',
        'InstallMissingFor' => 'Missing for',
        'InstallCleanDirectory' => 'Removing GCstar\'s files in directory: ',
        'InstallCopyDirectory' => 'Copying files in directory: ',
        'InstallCopyDesktop' => 'Copying desktop file in: ',
        
#Update
        'UpdateUseProxy' => 'Proxy to use (just press enter if none): ',
        'UpdateNoPermission' => 'Write permission denied in this directory: ',
        'UpdateNone' => 'No update have been found',
        'UpdateFileNotFound' => 'File not found',

 #Splash
        'SplashInit' => 'Inizio',
        'SplashLoad' => 'Caricamento films',
        'SplashDisplay' => 'Displaying Collection',
        'SplashDone' => 'Pronto',

#Import from GCfilms
        'GCfilmsImportQuestion' => 'It seems you were using GCfilms before. What do you want to import from GCfilms to GCstar (it won\'t impact GCfilms if you still want to use it)?',
        'GCfilmsImportOptions' => 'Settings',
        'GCfilmsImportData' => 'Movies list',

#Menus
        'MenuFile' => 'Film',
            'MenuNewList' => 'Nuova lista film',
            'MenuHistory' => 'Ultimi files aperti',
            'MenuLend' => 'Visualizza films prestati',
            'MenuImport' => 'Importa',
            'MenuExport' => 'Esporta',

		'MenuEdit'  => 'Modifica',
       	    'MenuDuplicate' => '_Duplicate item',
    		'MenuEditDeleteCurrent' => 'Cancella film corrente',
            'MenuEditFields' => '_Change collection fields',
    		'MenuEditLockItems' => 'Blocca la lista',

        'MenuDisplay' => 'Visualizzazione',
            'MenuAdvancedSearch' => 'A_dvanced Search',
            'MenuViewAllItems' => 'Vedi tutti i films',
            'MenuNoFilter' => 'Tutti',
        
        'MenuConfiguration' => 'Configurazione',
            'MenuDisplayOptions' => 'Informazioni da visulizzare',
            'MenuBorrowers' => 'Prestatari',
            'MenuGenresConversion' => 'Genre _Conversion',

        'MenuBookmarks' => 'My _Collections',
            'MenuBookmarksAdd' => '_Add current collection',
            'MenuBookmarksEdit' => '_Edit bookmarked collections',

        'MenuHelp' => '?',
            'MenuHelpContent' => '?',
            'MenuAllPlugins' => 'View _plugins',
            'MenuBugReport' => 'Report a _bug',
            'MenuAbout' => 'Circa GCstar',

        'MenuNewWindow' => 'Visulizza films in una nuova finestra',
        
        'ContextExpandAll' => 'Expand all',
        'ContextCollapseAll' => 'Collapse all',

        'DialogEnterNumber' => 'Please enter value',

        'RemoveConfirm' => 'Desideri rimuovere questo film?',
        'DefaultNewItem' => 'New item',
        'NewItemTooltip' => 'Aggiungi un nuovo film',
        'NoItemFound' => 'Nessun film è stato trovato. Desideri effettuare una ricerca su un altro percorso?',
        'OpenList' => 'Scegli la lista film',
        'SaveList' => 'Scegli dove salvare la lista',
        'SaveListTooltip' => 'Salva la lista corrente',
        'SaveCurrentList' => 'In primo luogo specifica dove salvare la lista corrente',
        'SaveUnsavedChanges' => 'There are unsaved changes in your collection. Do you want to save them?',
        'SaveDontSave' => 'Don\'t save',
        'PreferencesTooltip' => 'Imposta preferenze',
        'ViewTooltip' => 'Cambia il tipo di liste',
        'PlayTooltip' => 'Play video associated to the item',

        'StatusSave' => 'Saving...',
        'StatusLoad' => 'Loading...',
        'StatusSearch' => 'Ricerca in progresso...',
        'StatusGetInfo' => 'Ottenere le informazioni...',
        'StatusGetImage' => 'Ottenere immagine...',
                
        'SaveError' => 'Non può conservare la lista di film. Controlli prego i diritti di accesso e lo spazio libero del disco',
        'OpenError' => 'Non può aprire la lista di films. Controlli prego i diritti di accesso.',
        'OpenFormatError' => 'Non può aprire la lista di films.',
        'ImageError' => 'L\'indice selezionato per conservare le immagini non è corretto.  Selezioni prego altro.',
        'OptionsCreationError'=> 'Non può generare la lista di opzioni: ',
        'OptionsOpenError'=> 'Non può aprire la lista di opzioni: ',
        'OptionsSaveError'=> 'Non può conservare la lista di opzioni: ',

        'RandomTooltip' => 'Cosa vedo questa sera?',
        'RandomError'=> 'Tu non hai film non visti',
        'RandomEnd'=> 'Non ci sono più films',
        'RandomNextTip'=> 'Prossimo suggerimento',
        'RandomOkTip'=> 'Accetto questo film',
        
        'AboutTitle' => 'Circa GCstar',
        'AboutDesc' => 'Catalogo di film Gtk2',
        'AboutVersion' => 'Versione',
        'AboutTeam' => 'Team',
        'AboutWho' => 'Tian : Gestione di progetti, Programmazione
Adolfo González : Programmazione',
        'AboutLicense' => 'Distribuito sotto i termini dello GNU GPL
Logos Copyright le Spektre
http://le-spektre.org',
        'AboutTranslation' => 'Traduzione italiana da Ernic',
        'AboutDesign' => 'Logo and webdesign by le Spektre',

        'ToolbarRandom' => 'Stasera',

        'ModelsSelect' => 'Select a collection type',
        'ModelsPersonal' => 'Personal models',
        'ModelsDefault' => 'Default models',
        'ModelsList' => 'Collection definition',
        'ModelSettings' => 'Collection settings',
        'ModelNewType' => 'New collection type',
        'ModelName' => 'Name of the collection type:',
		'ModelFields' => 'Fields',
		'ModelOptions'	=> 'Options',
		'ModelFilters'	=> 'Filters',
        'ModelNewField' => 'New field',
        'ModelFieldInformation' => 'Information',
        'ModelFieldName' => 'Label:',
        'ModelFieldType' => 'Type:',
        'ModelFieldGroup' => 'Group:',
        'ModelFieldValues' => 'Values',
        'ModelFieldInit' => 'Default:',
        'ModelFieldMin' => 'Minimum:',
        'ModelFieldMax' => 'Maximum:',
        'ModelFieldList' => 'Values list:',
        'ModelFieldListLegend' => '<i>Comma separated</i>',
        'ModelFieldTypeShortText' => 'Short text',
        'ModelFieldTypeLongText' => 'Long text',
        'ModelFieldTypeYesNo' => 'Yes/No',
        'ModelFieldTypeNumber' => 'Number',
        'ModelFieldTypeDate' => 'Date',
        'ModelFieldTypeOptions' => 'Pre-defined values list',
        'ModelFieldTypeImage' => 'Image',
        'ModelFieldTypeSingleList' => 'Simple list',
        'ModelFieldTypeFile' => 'File',
        'ModelFieldTypeFormatted' => 'Dependant on other fields',
        'ModelFieldParameters' => 'Parameters',
        'ModelFieldHasHistory' => 'Use an history',
        'ModelFieldFlat' => 'Display on one line',
        'ModelFieldStep' => 'Increment step:',
        'ModelFieldFileFormat' => 'File format:',
        'ModelFieldFileFile' => 'Simple file',
        'ModelFieldFileImage' => 'Image',
        'ModelFieldFileVideo' => 'Video',
        'ModelFieldFileAudio' => 'Audio',
        'ModelFieldFileProgram' => 'Program',
        'ModelFieldFileUrl' => 'URL',
        'ModelOptionsFields' => 'Fields to use',
        'ModelOptionsFieldsAuto' => 'Automatic',
        'ModelOptionsFieldsNone' => 'None',
        'ModelOptionsFieldsTitle' => 'As title',
        'ModelOptionsFieldsId' => 'As identifier',
        'ModelOptionsFieldsCover' => 'As cover',
        'ModelOptionsFieldsPlay' => 'For Play button',
        'ModelCollectionSettings' => 'Collection settings',
        'ModelCollectionSettingsLending' => 'Items could be borrowed',
        'ModelFilterActivated' => 'Should be in search box',
        'ModelFilterComparison' => 'Comparison',
        'ModelFilterContain' => 'Contains',
        'ModelFilterRange' => 'Range',
        'ModelFilterNumeric' => 'Comparison is numeric',
        'ModelFilterQuick' => 'Create a quick filter',
        'ModelTooltipName' => 'Use a name to re-use this model for many collections. If empty, the settings will be directly stored in the collection itself',
        'ModelTooltipLabel' => 'The field name as it will be displayed',
        'ModelTooltipGroup' => 'Used to group fields. Items with no value here will be in a default group',
        'ModelTooltipHistory' => 'Should the previous entered values be stored in a list associated to the field',
        'ModelTooltipFormat' => 'This format is used to determine the action to open the file with the Play button',
        'ModelTooltipLending' => 'This will add some fields to manage lendings',
        'ModelTooltipNumeric' => 'Should the values be consider as numbers for comparison',
        'ModelTooltipQuick' => 'This will add a submenu in the Filters one',

        'ResultsTitle' => 'Seleziona un film',
        'ResultsNextTip' => 'Cerca nel prossimo sito',
        'ResultsPreview' => 'Preview',
        
        'OptionsTitle' => 'Preferenze',
        'OptionsBrowser' => 'Web browser',
        'OptionsPlayer' => 'Video player',
        'OptionsAudio' => 'Audio player',
        'OptionsImages' => 'Indice di immagini',
        'OptionsUseRelativePaths' => 'Use relative paths for images',
        'OptionsLayout' => 'Layout',
        'OptionsStatus' => 'Visualizza la barra di stato in fondo alla finestra',
        'OptionsWarning' => 'Avvertimento:  Le opzioni cambiate in questo pannello avranno effetto dopo il riavvio dell\' applicazione',
        'OptionsRemoveConfirm' => 'Chiedi conferma prima di rimuovere un film dalla lista',
        'OptionsAutoSave' => 'Salva automaticamente la lista dei film',
        'OptionsAutoLoad' => 'Load previous collection on startup',
        'OptionsSplash' => 'Mostra splashscreen',
        'OptionsImagesTitle' => 'Seleziona un indice',
        'OptionsProgramTitle' => 'Seleziona il programma per essere usato',
		'OptionsPlugins' => 'Siti da usare per le informazioni dei films',
		'OptionsAskPlugins' => 'Chiedi (Tutti i siti)',
		'OptionsPluginsMulti' => 'Molti siti',
		'OptionsPluginsMultiAsk' => 'Chiedi (Molti siti)',
		'OptionsPluginsList' => 'Configura la lista',
        'OptionsAskImport' => 'Seleziona i campi da importare',
		'OptionsProxy' => 'Usa un proxy',
        'OptionsLang' => 'Lingua',
        'OptionsMain' => 'Principale',
        'OptionsPaths' => 'Percorsi',
        'OptionsInternet' => 'Internet',
        'OptionsConveniences' =>'Strumenti',
        'OptionsDisplay' => 'Visualizzazione',
        'OptionsToolbar' => 'Toolbar',
        'OptionsToolbars' => {0 => 'Nessuno', 1 => 'Piccolo', 2 => 'Grande'},
        'OptionsToolbarPosition' => 'Position',
        'OptionsToolbarPositions' => {0 => 'Top', 1 => 'Bottom', 2 => 'Left', 3 => 'Right'},
        'OptionsView' => 'Items display',
        'OptionsViews' => {0 => 'Testo', 1 => 'Immagine', 2 => 'Dettagli'},
        'OptionsColumns' => 'Colonne',
        'OptionsMailer' => 'Metodo dei sendings',
        'OptionsSMTP' => 'Server',
        'OptionsFrom' => 'Mittente e-mail',
        'OptionsTransform' => 'Metti gli articoli alla fine dei titoli',
        'OptionsArticles' => 'Articoli (virgola separata)',
        'OptionsSearchStop' => 'L\'utente può arrestare una ricerca',
        'OptionsAlwaysOriginal' => 'Use main title as the original one if none present',
        'OptionsHistory' => 'Dimensione della cronologia',
        'OptionsClearHistory' => 'Cancella cronologia',
		'OptionsStyle' => 'Skin',
        'OptionsDontAsk' => 'Don\'t ask anymore',
        'OptionsPathProgramsGroup' => 'Applications',
        'OptionsProgramsSystem' => 'Use programs defined by system',
        'OptionsProgramsUser' => 'Use specified programs',
        'OptionsProgramsSet' => 'Set programs',
        'OptionsPathImagesGroup' => 'Images',
        'OptionsInternetDataGroup' => 'Data import',
        'OptionsInternetSettingsGroup' => 'Settings',
        'OptionsDisplayInformationGroup' => 'Information display',
        'OptionsDisplayArticlesGroup' => 'Articles',
        'OptionsImagesDisplayGroup' => 'Display',
        'OptionsImagesStyleGroup' => 'Style',
        'OptionsDetailedPreferencesGroup' => 'Preferences',
        'OptionsFeaturesConveniencesGroup' => 'Conveniences',
        'OptionsPicturesFormat' => 'Prefix to use for pictures:',
        'OptionsPicturesFormatInternal' => 'gcstar__',
        'OptionsPicturesFormatTitle' => 'Title or name of the associated item',
        'OptionsPicturesWorkingDir' => '%WORKING_DIR% or . will be replaced with collection directory (use only on beginning of path)',
        'OptionsPicturesFileBase' => '%FILE_BASE% will be replaced by collection file name without suffix (.gcs)',
        'OptionsPicturesWorkingDirError' => '%WORKING_DIR% could only be used on the beginning of the path for pictures',
        'OptionsConfigureMailers' => 'Configure mailing programs',

        'ImagesOptionsButton' => 'Settings',
        'ImagesOptionsTitle' => 'Settings for images list',
        'ImagesOptionsSelectColor' => 'Seleziona un colore',
        'ImagesOptionsBg' => 'Background',
        'ImagesOptionsBgPicture' => 'Usa un\'immagine di background',
        'ImagesOptionsFg'=> 'Selezione',
        'ImagesOptionsBgTooltip' => 'Cambia colore di background',
        'ImagesOptionsFgTooltip'=> 'Cambia il colore di selezione',
        'ImagesOptionsSizeLabel' => 'Size',
        'ImagesOptionsSizeList' => {0 => 'Very Small', 1 => 'Small', 2 => 'Medium', 3 => 'Large', 4 => 'Extra Large'},
        'ImagesOptionsSizeTooltip' => 'Select image size',
		        
        'DetailedOptionsTitle' => 'Settings for detailed list',
        'DetailedOptionsImageSize' => 'Images size',
        'DetailedOptionsGroupItems' => 'Group items by',
		'DetailedOptionsFields' => 'Scegli i campi da visualizzare',
		'DetailedOptionsMasterOption' => 'Group master is',
		'DetailedOptionsMasterGenerated' => 'Auto generated',
		'DetailedOptionsMasterOrdered' => 'Determined by',

        'ExtractButton' => 'Information',
        'ExtractTitle' => 'File information',
        'ExtractImport' => 'Use values',

        'FieldsListOpen' => 'Load a fields list from a file',
        'FieldsListSave' => 'Save fields list to a file',
        'FieldsListError' => 'This fields list cannot be used with this kind of collection',

        'ExportTitle' => 'Lista film dell\'esportazione',
        'ExportFilter' => 'Export only displayed items',
        'ExportFieldsTitle' => 'Campi da esportare',
        'ExportFieldsTip' => 'Campi prescelti che desideri esportare',
        'ExportWithPictures' => 'Copia le immagini in una sub directory',

        'ImportListTitle' => 'Importa un\'altra lista',
        'ImportExportData' => 'Data',
        'ImportExportFile' => 'Lista',
        'ImportExportSave' => 'Seleziona la lista',
        'ImportExportFieldsUnused' => 'Campi inutilizzati',
        'ImportExportFieldsUsed' => 'Campi usati',
        'ImportExportFieldsFill' => 'Tutti i campi',
        'ImportExportFieldsClear' => 'Nessun campo',
        'ImportExportFieldsEmpty' => 'Dovete scegliere almeno un campo',
        'ImportExportFileEmpty' => 'Devi specificare un nome per il file',
        'ImportFieldsTitle' => 'Campi da importare',
        'ImportFieldsTip' => 'Scegli i campi che vuoi importare',
        'ImportNewList' => 'Crea una nuova lista',
        'ImportCurrentList' => 'Aggiungi alla lista corrente',
        'ImportDropError' => 'There was an error opening at least one file. Previous list will be reloaded.',
        'ImportGenerateId' => 'Generate identifier for each item',

        'FileOverwrite' => 'Questa lista già esiste. Desideri sovrascrivere?',

        'PanelCompact' => 'Compact',
        'PanelReadOnly' => 'Read Only',
        'PanelForm' => 'Etichette',

        'PanelSearchButton' => 'Fetch Information',
        'PanelSearchTip' => 'Cerca informazioni secondo il titolo del film inserito',
        'PanelImageTipOpen' => 'Clicca sull\'immagine per sceglierne un\'altra.',
        'PanelImageTipView' => 'Click on the picture to view it in real size.',
        'PanelImageTipMenu' => ' Right click for more options.',
        'PanelImageTitle' => 'Sceglie un\'immagine',
        'PanelImageNoImage' => 'No image',
        'PanelSelectFileTitle' => 'Select a file',
        'PanelRestoreDefault' => 'Restore default',

        'PanelFrom' =>'From',
        'PanelTo' =>'To',

        'PanelWeb' => 'Leggi informazioni del film',
        'PanelWebTip' => 'Leggi informazioni su questo film disponibili sul web',
        'PanelRemoveTip' => 'Rimuovi il film corrente',

        'PanelDateSelect' => 'Scegli una data',
        'PanelNobody' => 'Nessuno',
        'PanelUnknown' => 'Sconosciuto',
        'PanelAdded' => 'Add date',
        'PanelLocation' => 'Luogo',
        
        'PanelLending' => 'Prestiti',
        'PanelBorrower' => 'Prestiti',
        'PanelLendDate' => 'Data',
        'PanelHistory' => 'Cronologia',
        'PanelReturned' => 'Film restituito',
        'PanelReturnDate' => 'Data restituzione',
        'PanelLendedYes' => 'Lended',
        'PanelLendedNo' => 'Available',

        'CheckUndef' => 'Nessun problema',
        'CheckYes' => 'Sì',
        'CheckNo' => 'No',

        'ToolbarAll' => 'Visulizza tutto',
        'ToolbarAllTooltip' => 'Visulizza tutti i films',
        'ToolbarGroupBy' => 'Group by',
        'ToolbarGroupByTooltip' => 'Select the field to use to group items in list',
               
        'PluginsTitle' => 'Cerca un film',
        'PluginsQuery' => 'Query',
        'PluginsFrame' => 'Cerca un sito',
        'PluginsLogo' => 'Logo',
        'PluginsName' => 'Name',
        'PluginsSearchFields' => 'Search fields',
        'PluginsAuthor' => 'Author',
        'PluginsLang' => 'Language',
        'PluginsUseSite' => 'Use selected site for future searches',

        'BorrowersTitle' => 'Configurazione di chi prende in prestito',
        'BorrowersList' => 'Prestatari',
        'BorrowersName' => 'Nome',
        'BorrowersEmail' => 'E-mail',
        'BorrowersAdd' => 'Aggiungi',
        'BorrowersRemove' => 'Elimina',
        'BorrowersEdit' => 'Modificare',
        'BorrowersTemplate' => 'Mail template',
        'BorrowersSubject' => 'Oggetto',
        'BorrowersNotice1' => '%1 sarà restituito con il nome di chi prende in prestito',
        'BorrowersNotice2' => '%2 sarà restituito con il titolo del film',
        'BorrowersNotice3' => '%3 sarà restituito con la data del prestito',

        'BorrowersImportTitle' => 'Import borrowers information',
        'BorrowersImportType' => 'File format:',
        'BorrowersImportFile' => 'File:',

        'BorrowedTitle' => 'Film prestati',
        'BorrowedDate' => 'Da',

        'MailTitle' => 'Manda un e-mail',
        'MailFrom' => 'Da: ',
        'MailTo' => 'A: ',
        'MailSubject' => 'Oggetto: ',
        'MailSmtpError' => 'Problema di connessione al server SMTP',
        'MailSendmailError' => 'Problema nell\'inviare l\'email',

        'SearchTooltip' => 'Cerca in tutti i films',
        'SearchTitle' => 'Cerca',
        
        'QueryReplaceField' => 'Field to replace',
        'QueryReplaceOld' => 'Nome corrente',
        'QueryReplaceNew' => 'Nuovo nome',
        'QueryReplaceLaunch' => 'Replace',
        
        'ImportWindowTitle' => 'Scegli i campi da importare',
        'ImportViewPicture' => 'Visualizza immagine',
        'ImportSelectAll' => 'Aggiungi tutti',
        'ImportSelectNone' => 'Rimuovi tutti',

        'MultiSiteTitle' => 'Sito da usare per le ricerche',
        'MultiSiteUnused' => 'Plugins inutilizzati',
        'MultiSiteUsed' => 'Plugins da usare',
        'MultiSiteLang' => 'Riempi la lista con il plugins inglese',
        'MultiSiteEmptyError' => 'Hai una lista di siti vuota',
        'MultiSiteClear' => 'Pulisci la lista',

        'DisplayOptionsTitle' => 'Oggetti da visualizzare',
        'DisplayOptionsAll' => 'Scegli tutto',
        'DisplayOptionsSearch' => 'Bottone ricerche',

        'GenresTitle' => 'Genre Conversion',
        'GenresCategoryName' => 'Genre to use',
        'GenresCategoryMembers' => 'Genre to replace',
        'GenresLoad' => 'Load a list',
        'GenresExport' => 'Save list to a file',
        'GenresModify' => 'Edit conversion',

        'PropertiesName' => 'Collection name',
        'PropertiesOwner' => 'Owner',
        'PropertiesEmail' => 'Email',
        'PropertiesDescription' => 'Description',
        'PropertiesFile' => 'File Information',
        'PropertiesFilePath' => 'Full path',
        'PropertiesItemsNumber' => 'Number of items',
        'PropertiesFileSize' => 'Size',
        'PropertiesFileSizeSymbols' => ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
        'PropertiesCollection' => 'Collection properties',

        'MailProgramsTitle' => 'Programs for mail sending',
        'MailProgramsName' => 'Name',
        'MailProgramsCommand' => 'Command line',
        'MailProgramsRestore' => 'Restore defaults',
        'MailProgramsAdd' => 'Add a program',
        'MailProgramsInstructions' => 'In command line, some substitutions are made:
 %f is replaced with user\'s e-mail address.
 %t is replaced with the recipient address.
 %s is replaced with the subject of the message.
 %b is replaced with the body of the message.',

        'BookmarksBookmarks' => 'Bookmarks',
        'BookmarksFolder' => 'Directory',
        'BookmarksLabel' => 'Label',
        'BookmarksPath' => 'Path',
        'BookmarksNewFolder' => 'New folder',

        'AdvancedSearchType' => 'Type of search',
        'AdvancedSearchTypeAnd' => 'Items matching all criteria',
        'AdvancedSearchTypeOr' => 'Items matching at least one criterion',
        'AdvancedSearchCriteria' => 'Criteria',
    );
}
1;
